@@ -90,25 +90,18 @@ asInit d reset ui@UIState{
         excludeforecastq Nothing  =  -- not:date:tomorrow- not:tag:generated-transaction
           And [
              Not (Date $ DateSpan (Just $ addDays 1 d) Nothing)
-            ,Not (Tag "generated-transaction" Nothing)
+            ,Not generatedTransactionTag
           ]
 
     -- run the report
-    (items,_total) = report ropts' q j
-      where
-                 -- XXX in historical mode, --forecast throws off the starting balances
-        report | balancetype_ ropts == HistoricalBalance = balanceReportFromMultiBalanceReport
-               | otherwise                               = balanceReport
-                    -- still using the old balanceReport for change reports as it
-                    -- does not include every account from before the report period
-
+    (items,_total) = balanceReport ropts' q j
 
     -- pre-render the list items
     displayitem (fullacct, shortacct, indent, bal) =
       AccountsScreenItem{asItemIndentLevel        = indent
                         ,asItemAccountName        = fullacct
                         ,asItemDisplayAccountName = replaceHiddenAccountsNameWith "All" $ if tree_ ropts' then shortacct else fullacct
-                        ,asItemRenderedAmounts    = map showAmountWithoutPrice amts -- like showMixedAmountOneLineWithoutPrice
+                        ,asItemRenderedAmounts    = map (showAmountWithoutPrice False) amts
                         }
       where
         Mixed amts = normaliseMixedAmountSquashPricesForDisplay $ stripPrices bal
@@ -123,7 +116,7 @@ asInit d reset ui@UIState{
                         }
 
 
-asInit _ _ _ = error "init function called with wrong screen type, should not happen"
+asInit _ _ _ = error "init function called with wrong screen type, should not happen"  -- PARTIAL:
 
 asDraw :: UIState -> [Widget Name]
 asDraw UIState{aopts=_uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
@@ -215,8 +208,10 @@ asDraw UIState{aopts=_uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
             quickhelp = borderKeysStr' [
                ("?", str "help")
 --              ,("RIGHT", str "register")
+              ,("t", renderToggle (tree_ ropts) "list" "tree")
+              -- ,("t", str "tree")
+              -- ,("l", str "list")
               ,("-+", str "depth")
-              ,("T", renderToggle (tree_ ropts) "flat" "tree")
               ,("H", renderToggle (not ishistorical) "end-bals" "changes")
               ,("F", renderToggle1 (isJust $ forecast_ ropts) "forecast")
               --,("/", "filter")
@@ -227,7 +222,7 @@ asDraw UIState{aopts=_uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
               ,("q", str "quit")
               ]
 
-asDraw _ = error "draw function called with wrong screen type, should not happen"
+asDraw _ = error "draw function called with wrong screen type, should not happen"  -- PARTIAL:
 
 asDrawItem :: (Int,Int) -> Bool -> AccountsScreenItem -> Widget Name
 asDrawItem (acctwidth, balwidth) selected AccountsScreenItem{..} =
@@ -291,7 +286,7 @@ asHandle ui0@UIState{
 
     Help ->
       case ev of
-        VtyEvent (EvKey (KChar 'q') []) -> halt ui
+        -- VtyEvent (EvKey (KChar 'q') []) -> halt ui
         VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
         VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
         _                    -> helpHandle ui ev
@@ -329,11 +324,11 @@ asHandle ui0@UIState{
         VtyEvent (EvKey (KChar '-') []) -> continue $ regenerateScreens j d $ decDepth ui
         VtyEvent (EvKey (KChar '_') []) -> continue $ regenerateScreens j d $ decDepth ui
         VtyEvent (EvKey (KChar c)   []) | c `elem` ['+','='] -> continue $ regenerateScreens j d $ incDepth ui
-        VtyEvent (EvKey (KChar 't') [])    -> continue $ regenerateScreens j d $ setReportPeriod (DayPeriod d) ui
+        VtyEvent (EvKey (KChar 'T') []) -> continue $ regenerateScreens j d $ setReportPeriod (DayPeriod d) ui
 
         -- display mode/query toggles
         VtyEvent (EvKey (KChar 'H') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleHistorical ui
-        VtyEvent (EvKey (KChar 'T') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleTree ui
+        VtyEvent (EvKey (KChar 't') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleTree ui
         VtyEvent (EvKey (KChar 'Z') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleEmpty ui
         VtyEvent (EvKey (KChar 'R') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleReal ui
         VtyEvent (EvKey (KChar 'U') []) -> asCenterAndContinue $ regenerateScreens j d $ toggleUnmarked ui
@@ -398,7 +393,7 @@ asHandle ui0@UIState{
   where
     journalspan = journalDateSpan False j
 
-asHandle _ _ = error "event handler called with wrong screen type, should not happen"
+asHandle _ _ = error "event handler called with wrong screen type, should not happen"  -- PARTIAL:
 
 asSetSelectedAccount a s@AccountsScreen{} = s & asSelectedAccount .~ a
 asSetSelectedAccount _ s = s
