@@ -16,9 +16,6 @@ import Control.Concurrent (threadDelay)
 import Control.Concurrent.Async
 import Control.Monad
 -- import Control.Monad.IO.Class (liftIO)
-#if !MIN_VERSION_vty(5,15,0)
-import Data.Default (def)
-#endif
 -- import Data.Monoid              --
 import Data.List
 import Data.List.Extra (nubSort)
@@ -33,11 +30,7 @@ import System.FilePath
 import System.FSNotify
 import Brick
 
-#if MIN_VERSION_brick(0,16,0)
 import qualified Brick.BChan as BC
-#else
-import Control.Concurrent.Chan (newChan, writeChan)
-#endif
 
 import Hledger
 import Hledger.Cli hiding (progname,prognameandversion)
@@ -50,13 +43,11 @@ import Hledger.UI.RegisterScreen
 
 ----------------------------------------------------------------------
 
-#if MIN_VERSION_brick(0,16,0)
 newChan :: IO (BC.BChan a)
 newChan = BC.newBChan 10
 
 writeChan :: BC.BChan a -> a -> IO ()
 writeChan = BC.writeBChan
-#endif
 
 
 main :: IO ()
@@ -92,7 +83,7 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
          reportopts_= ropts{
             -- incorporate any depth: query args into depth_,
             -- any date: query args into period_
-            depth_ =depthfromoptsandargs,
+            depth_ =queryDepth q,
             period_=periodfromoptsandargs,
             query_ =unwords -- as in ReportOptions, with same limitations
                     $ collectopts filteredQueryArg (rawopts_ copts),
@@ -107,9 +98,8 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
       }
       where
         q = queryFromOpts d ropts
-        depthfromoptsandargs = case queryDepth q of 99999 -> Nothing
-                                                    d     -> Just d
-        datespanfromargs = queryDateSpan (date2_ ropts) $ fst $ parseQuery d (T.pack $ query_ ropts)
+        datespanfromargs = queryDateSpan (date2_ ropts) $ fst $
+                           either error' id $ parseQuery d (T.pack $ query_ ropts)  -- PARTIAL:
         periodfromoptsandargs =
           dateSpanAsPeriod $ spansIntersect [periodAsDateSpan $ period_ ropts, datespanfromargs]
         filteredQueryArg = \case
@@ -130,15 +120,18 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
       -- to that as usual.
       Just apat -> (rsSetAccount acct False registerScreen, [ascr'])
         where
-          acct = headDef
-                 (error' $ "--register "++apat++" did not match any account")
-                 $ filter (regexMatches apat . T.unpack) $ journalAccountNames j
+          acct = headDef (error' $ "--register "++apat++" did not match any account")  -- PARTIAL:
+                 . filterAccts $ journalAccountNames j
+          filterAccts = case toRegexCI apat of
+              Right re -> filter (regexMatch re . T.unpack)
+              Left  _  -> const []
           -- Initialising the accounts screen is awkward, requiring
           -- another temporary UIState value..
           ascr' = aScreen $
                   asInit d True
                     UIState{
-                      aopts=uopts'
+                     astartupopts=uopts'
+                    ,aopts=uopts'
                     ,ajournal=j
                     ,aScreen=asSetSelectedAccount acct accountsScreen
                     ,aPrevScreens=[]
@@ -149,7 +142,8 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
       (sInit scr) d True $
         (if change_ uopts' then toggleHistorical else id) -- XXX
           UIState{
-            aopts=uopts'
+           astartupopts=uopts'
+          ,aopts=uopts'
           ,ajournal=j
           ,aScreen=scr
           ,aPrevScreens=prevscrs
@@ -232,11 +226,7 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
             )
 
         -- and start the app. Must be inside the withManager block
-#if MIN_VERSION_vty(5,15,0)
         let mkvty = mkVty mempty
-#else
-        let mkvty = mkVty def
-#endif
 #if MIN_VERSION_brick(0,47,0)
         vty0 <- mkvty
         void $ customMain vty0 mkvty (Just eventChan) brickapp ui
