@@ -1,15 +1,12 @@
-{-# LANGUAGE CPP #-}
 {- | UIState operations. -}
 
+{-# LANGUAGE NamedFieldPuns    #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE RecordWildCards   #-}
 
 module Hledger.UI.UIState
 where
 
-#if !MIN_VERSION_brick(0,19,0)
-import Brick
-#endif
 import Brick.Widgets.Edit
 import Data.List
 import Data.Text.Zipper (gotoEOL)
@@ -49,14 +46,14 @@ uiShowStatus copts ss =
     _ -> map showstatus $ sort ss
   where
     numstatuses = length [minBound..maxBound::Status]
-    style = maybeintopt "status-toggles" $ rawopts_ copts
+    style = maybeposintopt "status-toggles" $ rawopts_ copts
     showstatus Cleared  = "cleared"
     showstatus Pending  = "pending"
     showstatus Unmarked = "unmarked"
 
 reportOptsToggleStatusSomehow :: Status -> CliOpts -> ReportOpts -> ReportOpts
 reportOptsToggleStatusSomehow s copts ropts =
-  case maybeintopt "status-toggles" $ rawopts_ copts of
+  case maybeposintopt "status-toggles" $ rawopts_ copts of
      Just 2 -> reportOptsToggleStatus2 s ropts
      Just 3 -> reportOptsToggleStatus3 s ropts
 --     Just 4 -> reportOptsToggleStatus4 s ropts
@@ -135,6 +132,16 @@ valuationToggleValue :: Maybe ValuationType -> Maybe ValuationType
 valuationToggleValue (Just (AtDefault _)) = Nothing
 valuationToggleValue _                    = Just $ AtDefault Nothing
 
+-- | Set hierarchic account tree mode.
+setTree :: UIState -> UIState
+setTree ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{accountlistmode_=ALTree}}}}
+
+-- | Set flat account list mode.
+setList :: UIState -> UIState
+setList ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{accountlistmode_=ALFlat}}}}
+
 -- | Toggle between flat and tree mode. If current mode is unspecified/default, assume it's flat.
 toggleTree :: UIState -> UIState
 toggleTree ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
@@ -225,23 +232,31 @@ setReportPeriod :: Period -> UIState -> UIState
 setReportPeriod p ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
   ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{period_=p}}}}
 
+-- | Clear any report period limits.
+resetReportPeriod :: UIState -> UIState
+resetReportPeriod = setReportPeriod PeriodAll
+
 -- | Apply a new filter query.
 setFilter :: String -> UIState -> UIState
 setFilter s ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
   ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{query_=s}}}}
 
--- | Clear all filters/flags.
+-- | Reset some filters & toggles.
 resetFilter :: UIState -> UIState
 resetFilter ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
   ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{
-     accountlistmode_=ALFlat
-    ,empty_=True
+     empty_=True
     ,statuses_=[]
     ,real_=False
     ,query_=""
     --,period_=PeriodAll
     }}}}
 
+-- | Reset all options state to exactly what it was at startup
+-- (preserving any command-line options/arguments).
+resetOpts :: UIState -> UIState
+resetOpts ui@UIState{astartupopts} = ui{aopts=astartupopts}
+
 resetDepth :: UIState -> UIState
 resetDepth ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
   ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{depth_=Nothing}}}}
@@ -289,11 +304,7 @@ getDepth UIState{aopts=UIOpts{cliopts_=CliOpts{reportopts_=ropts}}} = depth_ rop
 showMinibuffer :: UIState -> UIState
 showMinibuffer ui = setMode (Minibuffer e) ui
   where
-#if MIN_VERSION_brick(0,19,0)
     e = applyEdit gotoEOL $ editor MinibufferEditor (Just 1) oldq
-#else
-    e = applyEdit gotoEOL $ editor MinibufferEditor (str . unlines) (Just 1) oldq
-#endif
     oldq = query_ $ reportopts_ $ cliopts_ $ aopts ui
 
 -- | Close the minibuffer, discarding any edit in progress.
@@ -330,7 +341,9 @@ popScreen ui = ui
 
 resetScreens :: Day -> UIState -> UIState
 resetScreens d ui@UIState{aScreen=s,aPrevScreens=ss} =
-  (sInit topscreen) d True $ resetDepth $ resetFilter $ closeMinibuffer ui{aScreen=topscreen, aPrevScreens=[]}
+  (sInit topscreen) d True $
+  resetOpts $
+  closeMinibuffer ui{aScreen=topscreen, aPrevScreens=[]}
   where
     topscreen = case ss of _:_ -> last ss
                            []  -> s
